;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-roam" "20250927.2243"
  "A database abstraction layer for Org-mode."
  '((emacs         "26.1")
    (dash          "2.13")
    (org           "9.6")
    (emacsql       "4.1.0")
    (magit-section "3.0.0"))
  :url "https://github.com/org-roam/org-roam"
  :commit "41f9a10be587b47454ca8ef26f6a8247605cbe34"
  :revdesc "41f9a10be587"
  :keywords '("org-mode" "roam" "convenience")
  :authors '(("Jethro Kuan" . "jethrokuan95@gmail.com"))
  :maintainers '(("Jethro Kuan" . "jethrokuan95@gmail.com")))
